households.Household (Household) — amici1

# `households.Household` (Household)

Household(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks, payment_term, partner_ptr, type)

Master tables : households.Households (Households)

Slave tables : addresses.AddressesByPartner (Addresses), households.MembersByHousehold (Household Members), ledger.MovementsByPartner (Movements), lists.MembersByPartner (List memberships), phones.ContactDetailsByPartner (Contact details), sepa.AccountsByPartner (Bank accounts), topics.InterestsByPartner (Interests)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- e-mail address (email) : The primary email address.

- Language (language) : The language to use when communicating with this partner.

- URL (url) : See `<django.db.models.fields.URLField: url>`.

- Phone (phone) : The primary phone number.

- GSM (gsm) : The primary mobile phone number.

- Fax (fax) : See `<django.db.models.fields.CharField: fax>`.

- Country (country) : See `<django.db.models.fields.related.ForeignKey: country>`.

- Locality (city) : The locality, i.e. usually a village, city or town.

- Zip code (zip_code) : See `<django.db.models.fields.CharField: zip_code>`.

- County (region) : See `<django.db.models.fields.related.ForeignKey: region>`.

- Address line before street (addr1) : Address line before street

- Street prefix (street_prefix) : Text to print before name of street, but to ignore for sorting.

- Street (street) : Name of street, without house number.

- No. (street_no) : House number.

- Box (street_box) : Text to print after street number on the same line.

- Address line after street (addr2) : Address line to print below street line.

- Name prefix (prefix) : An optional name prefix. For organisations this is inserted before the name, for persons this is inserted between first name and last name.

- Name (name) : The full name of this partner. Used for alphabetic sorting.

- Remarks (remarks) : See `<django.db.models.fields.TextField: remarks>`.

- Payment term (payment_term) : The default payment term for sales invoices to this customer.

- Purchase account (purchase_account) : The general account to suggest as default value in purchase invoices from this partner.

- Partner (partner_ptr) : See `<django.db.models.fields.related.OneToOneField: partner_ptr>`.

- Household Type (type) : The type of this household. See household types

- Name (name_column) : See `lino_xl.lib.households.models.Household.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.households.models.Household.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.households.models.Household.overview`.

- Contact details (contact_details) : See `lino_xl.lib.households.models.Household.contact_details`.

- See as (mti_navigator) : A virtual field which defines buttons for switching between the different views.

- Address (address_column) : See `lino_xl.lib.households.models.Household.address_column`.

- Municipality (municipality) : The municipality, i.e. either the city or a parent of it.

Referenced from households.Member.household

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
email | e-mail address | The primary email address.
language | Language | The language to use when communicating with this partner.
url | URL |
phone | Phone | The primary phone number.
gsm | GSM | The primary mobile phone number.
fax | Fax |
country | Country |
city | Locality | The locality, i.e. usually a village, city or town.
zip_code | Zip code |
region | County |
addr1 | Address line before street | Address line before street
street_prefix | Street prefix | Text to print before name of street, but to ignore for sorting.
street | Street | Name of street, without house number.
street_no | No. | House number.
street_box | Box | Text to print after street number on the same line.
addr2 | Address line after street | Address line to print below street line.
prefix | Name prefix | An optional name prefix. For organisations this is inserted before the name, for persons this is inserted between first name and last name.
name | Name | The full name of this partner. Used for alphabetic sorting.
remarks | Remarks |
payment_term | Payment term | The default payment term for sales invoices to this customer.
purchase_account | Purchase account | The general account to suggest as default value in purchase invoices from this partner.
partner_ptr | Partner |
type | Household Type | The type of this household. See household types
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
contact_details | Contact details |
mti_navigator | See as | A virtual field which defines buttons for switching between the different views.
address_column | Address |
municipality | Municipality | The municipality, i.e. either the city or a parent of it.